# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic.v1 import BaseModel, Field, StrictInt, StrictStr


class DataVersionStatusResponse(BaseModel):
    """
    `DataVersionStatusResponse`
    """

    status_code: Optional[StrictInt] = Field(
        default=None,
        alias="statusCode",
        description="Numeric status code indicating the current state of data processing",
    )
    error_message_parsed: Optional[StrictStr] = Field(
        default=None,
        alias="errorMessageParsed",
        description="Human-readable error message if processing failed",
    )
    error_cause: Optional[StrictStr] = Field(
        default=None,
        alias="errorCause",
        description="Root cause of the error if processing failed",
    )
    error_code: Optional[StrictStr] = Field(
        default=None,
        alias="errorCode",
        description="Specific error code for programmatic error handling",
    )
    __properties = ["statusCode", "errorMessageParsed", "errorCause", "errorCode"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DataVersionStatusResponse:
        """Create an instance of DataVersionStatusResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DataVersionStatusResponse:
        """Create an instance of DataVersionStatusResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return DataVersionStatusResponse.parse_obj(obj)

        _obj = DataVersionStatusResponse.parse_obj(
            {
                "status_code": obj.get("statusCode"),
                "error_message_parsed": obj.get("errorMessageParsed"),
                "error_cause": obj.get("errorCause"),
                "error_code": obj.get("errorCode"),
            }
        )
        return _obj
